==> haskell-graphscc-1.0.4-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-graphscc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: GraphSCC
version: 1.0.4
id: GraphSCC-1.0.4-GVmzyXqIgqe3Q5GQSUHI1A
key: GraphSCC-1.0.4-GVmzyXqIgqe3Q5GQSUHI1A
license: BSD3
maintainer: diatchki@galois.com
synopsis: Tarjan'\''s algorithm for computing the strongly connected components of a graph.
description:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.
category: Algorithms
author: Iavor S. Diatchki
exposed: True
indefinite: False
exposed-modules:
    Data.Graph.SCC
hidden-modules: Data.Graph.ArraySCC
abi: 947a433335dc87a146d16c315aa11810
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/GraphSCC-1.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/GraphSCC-1.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/GraphSCC-1.0.4
hs-libraries: HSGraphSCC-1.0.4-GVmzyXqIgqe3Q5GQSUHI1A
depends:
    array-0.5.2.0 base-4.10.1.0 containers-0.5.10.2
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
haddock-interfaces: /usr/share/doc/haskell-graphscc/html/GraphSCC.haddock
haddock-html: /usr/share/doc/haskell-graphscc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphscc-1.0.4-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-graphscc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: GraphSCC
version: 1.0.4
id: GraphSCC-1.0.4-H3NchjVfsifDXhqutugzy
key: GraphSCC-1.0.4-H3NchjVfsifDXhqutugzy
license: BSD-3-Clause
maintainer: diatchki@galois.com
author: Iavor S. Diatchki
synopsis: Tarjan'\''s algorithm for computing the strongly connected components of a graph.
description:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.
category: Algorithms
abi: 6900163bc49f9f7f011368d0e47c28f7
exposed: True
exposed-modules:
    Data.Graph.SCC
hidden-modules: Data.Graph.ArraySCC
import-dirs: /usr/lib/ghc-8.4.2/site-local/GraphSCC-1.0.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/GraphSCC-1.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/GraphSCC-1.0.4
hs-libraries: HSGraphSCC-1.0.4-H3NchjVfsifDXhqutugzy
depends:
    array-0.5.2.0 base-4.11.1.0 containers-0.5.11.0
abi-depends: array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
haddock-interfaces: /usr/share/doc/haskell-graphscc/html/GraphSCC.haddock
haddock-html: /usr/share/doc/haskell-graphscc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
